==> pffloader-1.16.2-1.16.5-0.3.0-sources.jar: com/ptk671/pffloader/api/item/PffFoodComponent.java <==
package com.ptk671.pffloader.api.item;

import com.mojang.datafixers.util.Pair;
import java.util.List;
import net.minecraft.class_1293;
import net.minecraft.class_4174;

public class PffFoodComponent  {
    private int hunger;
    private boolean hunger_boolean = false;
    private float saturationModifier;
    private boolean saturationModifier_boolean = false;
    private boolean meat = false;
    private boolean alwaysEdible = false;
    private boolean snack = false;
    private List<Pair<class_1293, Float>> statusEffects;

    public PffFoodComponent hunger(int hunger) {
        this.hunger = hunger;
        this.hunger_boolean = true;
        return this;
    }

    public PffFoodComponent saturationModifier(float saturationModifier){
        this.saturationModifier = saturationModifier;
        this.saturationModifier_boolean = true;
        return this;
    }

    public PffFoodComponent meat(){
        this.meat = true;
        return this;
    }

    public PffFoodComponent alwaysEdible(){
        this.alwaysEdible = true;
        return this;
    }

    public PffFoodComponent snack(){
        this.snack = true;
        return this;
    }

    public PffFoodComponent statusEffects(List<Pair<class_1293, Float>> statusEffects){
        this.statusEffects = statusEffects;
        return this;
    }

    public class_4174 build() {
        class_4174.class_4175 foodComponent = new class_4174.class_4175();
        if(hunger_boolean)foodComponent.method_19238(hunger); foodComponent.method_19238(hunger);
        if(saturationModifier_boolean) foodComponent.method_19237(saturationModifier);
        if(snack) foodComponent.method_19241();
        if(statusEffects != null ) foodComponent.method_19237(saturationModifier);
        if(meat) foodComponent.method_19236();
        if(alwaysEdible) foodComponent.method_19240();
        return foodComponent.method_19242();
    }
}

==> pffloader-1.21-0.2.1-sources.jar: com/ptk671/pffloader/api/item/PffFoodComponent.java <==
package com.ptk671.pffloader.api.item;

import com.mojang.datafixers.util.Pair;
import java.util.List;
import net.minecraft.class_1293;
import net.minecraft.class_4174;

public class PffFoodComponent {
    private int hunger;
    private boolean hunger_boolean = false;
    private float saturationModifier;
    private boolean saturationModifier_boolean = false;
    private boolean meat = false;
    private boolean alwaysEdible = false;
    private boolean snack = false;
    private List<Pair<class_1293, Float>> statusEffects;

    public PffFoodComponent hunger(int hunger) {
        this.hunger = hunger;
        this.hunger_boolean = true;
        return this;
    }

    public PffFoodComponent saturationModifier(float saturationModifier){
        this.saturationModifier = saturationModifier;
        this.saturationModifier_boolean = true;
        return this;
    }

    public PffFoodComponent meat(){
        //Below 1.21
        this.meat = true;
        return this;
    }

    public PffFoodComponent alwaysEdible(){
        this.alwaysEdible = true;
        return this;
    }

    public PffFoodComponent snack(){
        this.snack = true;
        return this;
    }

    public PffFoodComponent statusEffects(List<Pair<class_1293, Float>> statusEffects){
        this.statusEffects = statusEffects;
        return this;
    }

    public class_4174 build() {
        class_4174.class_4175 foodComponent = new class_4174.class_4175();
        if(hunger_boolean)foodComponent.method_19238(hunger);
        if(saturationModifier_boolean) foodComponent.method_19237(saturationModifier);
        if(snack) foodComponent.method_19241();
        if(statusEffects != null ) foodComponent.method_19237(saturationModifier);
        if(alwaysEdible) foodComponent.method_19240();
        return foodComponent.method_19242();
    }
}
